

/***
*
*	Copyright (c) 1996-2001, Valve LLC. All rights reserved.
*	
*	This product contains software technology licensed from Id 
*	Software, Inc. ("Id Technology").  Id Technology (c) 1996 Id Software, Inc. 
*	All Rights Reserved.
*
*   Use, distribution, and modification of this source code and/or resulting
*   object code is restricted to non-commercial enhancements to products from
*   Valve LLC.  All other use, distribution, or modification is prohibited
*   without written permission from Valve LLC.
*
****/

#include "extdll.h"
#include "util.h"
#include "cbase.h"
#include "monsters.h"
#include "weapons.h"
#include "nodes.h"
#include "player.h"
#include "soundent.h"
#include "gamerules.h"

bool m_canfire = true;
#define ZOOM1 14

enum mp5_e
{
        MP5_LONGIDLE = 0,
        //MP5_IDLE1,
        //MP5_LAUNCH,
        MP5_RELOAD
        //MP5_DEPLOY
        //MP5_FIRE1,
        //MP5_FIRE2,
        //MP5_FIRE3,
};



LINK_ENTITY_TO_CLASS( weapon_mp5, CMP5 );
LINK_ENTITY_TO_CLASS( weapon_9mmAR, CMP5 );


//=========================================================
//=========================================================
int CMP5::SecondaryAmmoIndex( void )
{
	return m_iSecondaryAmmoType;
}

void CMP5::Spawn( )
{
	pev->classname = MAKE_STRING("weapon_9mmAR"); // hack to allow for old names
	Precache( );
        SET_MODEL(ENT(pev), "models/w_9mmAR.mdl");
	m_iId = WEAPON_MP5;

	m_iDefaultAmmo = MP5_DEFAULT_GIVE;

	FallInit();// get ready to fall down.
}


void CMP5::Precache( void )
{
        PRECACHE_MODEL("models/v_weapon.mdl");
	PRECACHE_MODEL("models/w_9mmAR.mdl");
	PRECACHE_MODEL("models/p_9mmAR.mdl");

        PRECACHE_MODEL("models/v_scope.mdl");

        //m_iShell = PRECACHE_MODEL ("models/shell.mdl");// brass shellTE_MODEL

        //PRECACHE_MODEL("models/grenade.mdl");   // grenade

        //PRECACHE_MODEL("models/w_9mmARclip.mdl");
	PRECACHE_SOUND("items/9mmclip1.wav");              

	PRECACHE_SOUND("items/clipinsert1.wav");
	PRECACHE_SOUND("items/cliprelease1.wav");

	PRECACHE_SOUND ("weapons/hks1.wav");// H to the K

        //PRECACHE_SOUND( "weapons/glauncher.wav" );
        //PRECACHE_SOUND( "weapons/glauncher2.wav" );

	PRECACHE_SOUND ("weapons/357_cock1.wav");

	m_usMP5 = PRECACHE_EVENT( 1, "events/mp5.sc" );
        //m_usMP52 = PRECACHE_EVENT( 1, "events/mp52.sc" );
}

int CMP5::GetItemInfo(ItemInfo *p)
{
	p->pszName = STRING(pev->classname);
	p->pszAmmo1 = "9mm";
	p->iMaxAmmo1 = _9MM_MAX_CARRY;
        p->pszAmmo2 = NULL;
        p->iMaxAmmo2 = -1;
	p->iMaxClip = MP5_MAX_CLIP;
	p->iSlot = 2;
	p->iPosition = 0;
	p->iFlags = 0;
	p->iId = m_iId = WEAPON_MP5;
	p->iWeight = MP5_WEIGHT;

	return 1;
}

int CMP5::AddToPlayer( CBasePlayer *pPlayer )
{
	if ( CBasePlayerWeapon::AddToPlayer( pPlayer ) )
	{
		MESSAGE_BEGIN( MSG_ONE, gmsgWeapPickup, NULL, pPlayer->pev );
			WRITE_BYTE( m_iId );
		MESSAGE_END();
		return TRUE;
	}
	return FALSE;
}

BOOL CMP5::Deploy( )
{
        return DefaultDeploy( "models/v_weapon.mdl", "models/p_9mmAR.mdl", MP5_LONGIDLE, "mp5" );
}


void CMP5::PrimaryAttack()
{
	// don't fire underwater
	if (m_pPlayer->pev->waterlevel == 3)
	{
		PlayEmptySound( );
		m_flNextPrimaryAttack = 0.15;
		return;
	}

	if (m_iClip <= 0)
	{
		PlayEmptySound();
		m_flNextPrimaryAttack = 0.15;
		return;
	}

	m_pPlayer->m_iWeaponVolume = NORMAL_GUN_VOLUME;
	m_pPlayer->m_iWeaponFlash = NORMAL_GUN_FLASH;

	m_iClip--;


	m_pPlayer->pev->effects = (int)(m_pPlayer->pev->effects) | EF_MUZZLEFLASH;

	// player "shoot" animation
	m_pPlayer->SetAnimation( PLAYER_ATTACK1 );

	Vector vecSrc	 = m_pPlayer->GetGunPosition( );
	Vector vecAiming = m_pPlayer->GetAutoaimVector( AUTOAIM_5DEGREES );
	Vector vecDir;

        // single player spread
        if ( m_pPlayer->pev->fov != 0 ) //IF I AM ZOOMED IN
                vecDir = m_pPlayer->FireBulletsPlayer( 1, vecSrc, vecAiming, VECTOR_CONE_0DEGREES, 8192, BULLET_PLAYER_MP5, 0, 0, m_pPlayer->pev, m_pPlayer->random_seed );
        else
                vecDir = m_pPlayer->FireBulletsPlayer( 1, vecSrc, vecAiming, VECTOR_CONE_3DEGREES, 8192, BULLET_PLAYER_MP5, 0, 0, m_pPlayer->pev, m_pPlayer->random_seed );

  int flags;
#if defined( CLIENT_WEAPONS )
	flags = FEV_NOTHOST;
#else
	flags = 0;
#endif

        PLAYBACK_EVENT_FULL( flags, m_pPlayer->edict(), m_usMP5, 0.0,
                (float *)&g_vecZero, (float *)&g_vecZero,
                vecDir.x, vecDir.y, 0, 0, 0, 0 );
/*
	if (!m_iClip && m_pPlayer->m_rgAmmo[m_iPrimaryAmmoType] <= 0)
		// HEV suit - indicate out of ammo condition
		m_pPlayer->SetSuitUpdate("!HEV_AMO0", FALSE, 0);
  */
	m_flNextPrimaryAttack = UTIL_WeaponTimeBase() + 0.1;

	if ( m_flNextPrimaryAttack < UTIL_WeaponTimeBase() )
		m_flNextPrimaryAttack = UTIL_WeaponTimeBase() + 0.1;

        //m_flTimeWeaponIdle = UTIL_WeaponTimeBase() + UTIL_SharedRandomFloat( m_pPlayer->random_seed, 10, 15 );
}



void CMP5::SecondaryAttack( void )
{
        //bc mp5zoom
        if ( !m_canfire)
                return;

        if ( m_pPlayer->pev->fov != 0 )
        {
                m_pPlayer->pev->viewmodel = MAKE_STRING("models/v_weapon.mdl");
                m_pPlayer->pev->fov = m_pPlayer->m_iFOV = 0; // 0 means reset to default fov
        }
        else if ( m_pPlayer->pev->fov != ZOOM1 )
        {
                SetThink(&CMP5::Scope);
                pev->nextthink = gpGlobals->time + 0.01;
                m_pPlayer->pev->fov = m_pPlayer->m_iFOV = ZOOM1;
        }

        m_canfire = false;
}

void CMP5::Scope( void )
{
        m_pPlayer->pev->viewmodel = MAKE_STRING("models/v_scope.mdl");
}


void CMP5::Reload( void )
{
	if ( m_pPlayer->ammo_9mm <= 0 )
		return;

        if ( m_pPlayer->pev->fov != 0 )//IF I AM ZOOMED IN
                SecondaryAttack();

	DefaultReload( MP5_MAX_CLIP, MP5_RELOAD, 1.5 );
}


void CMP5::Holster( int skiplocal /* = 0 */ )
{
	m_fInReload = FALSE;// cancel any reload in progress.

        if ( m_pPlayer->pev->fov != 0 )
	{
		SecondaryAttack( );
	}
}




void CMP5::WeaponIdle( void )
{
	ResetEmptySound( );

	m_pPlayer->GetAutoaimVector( AUTOAIM_5DEGREES );

        m_canfire = true;
/*
	if ( m_flTimeWeaponIdle > UTIL_WeaponTimeBase() )
		return;

	int iAnim;
	switch ( RANDOM_LONG( 0, 1 ) )
	{
	case 0:	
		iAnim = MP5_LONGIDLE;	
		break;
	
	default:
	case 1:
		iAnim = MP5_IDLE1;
		break;
	}

	SendWeaponAnim( iAnim );

	m_flTimeWeaponIdle = UTIL_SharedRandomFloat( m_pPlayer->random_seed, 10, 15 ); // how long till we do this again.
*/
}



class CMP5AmmoClip : public CBasePlayerAmmo
{
        CSprite     *pointersprite;
	void Spawn( void )
	{ 
		Precache( );
                SET_MODEL(ENT(pev), "models/w_9mmAR.mdl");
		CBasePlayerAmmo::Spawn( );

                pointersprite = CSprite::SpriteCreate( "sprites/point_gun.spr", pev->origin + Vector (0,0,72), TRUE) ;
	}
	void Precache( void )
	{
                PRECACHE_MODEL ("sprites/point_gun.spr");
                PRECACHE_MODEL ("models/w_9mmAR.mdl");
		PRECACHE_SOUND("items/9mmclip1.wav");
	}
	BOOL AddAmmo( CBaseEntity *pOther ) 
	{ 
		int bResult = (pOther->GiveAmmo( AMMO_MP5CLIP_GIVE, "9mm", _9MM_MAX_CARRY) != -1);
		if (bResult)
		{
			EMIT_SOUND(ENT(pev), CHAN_ITEM, "items/9mmclip1.wav", 1, ATTN_NORM);
                        UTIL_Remove( pointersprite );
		}
		return bResult;
	}
};
LINK_ENTITY_TO_CLASS( ammo_mp5clip, CMP5AmmoClip );
LINK_ENTITY_TO_CLASS( ammo_9mmAR, CMP5AmmoClip );



class CMP5Chainammo : public CBasePlayerAmmo
{
	void Spawn( void )
	{ 
		Precache( );
		SET_MODEL(ENT(pev), "models/w_chainammo.mdl");
		CBasePlayerAmmo::Spawn( );
	}
	void Precache( void )
	{
		PRECACHE_MODEL ("models/w_chainammo.mdl");
		PRECACHE_SOUND("items/9mmclip1.wav");
	}
	BOOL AddAmmo( CBaseEntity *pOther ) 
	{ 
		int bResult = (pOther->GiveAmmo( AMMO_CHAINBOX_GIVE, "9mm", _9MM_MAX_CARRY) != -1);
		if (bResult)
		{
			EMIT_SOUND(ENT(pev), CHAN_ITEM, "items/9mmclip1.wav", 1, ATTN_NORM);
		}
		return bResult;
	}
};
LINK_ENTITY_TO_CLASS( ammo_9mmbox, CMP5Chainammo );


//this has been changed to HANDGRENADE.
class CMP5AmmoGrenade : public CBasePlayerAmmo
{
        CSprite     *pointersprite;
	void Spawn( void )
	{ 
		Precache( );
                //SET_MODEL(ENT(pev), "models/w_ARgrenade.mdl");
                SET_MODEL(ENT(pev), "models/w_grenade.mdl");
		CBasePlayerAmmo::Spawn( );

                pointersprite = CSprite::SpriteCreate( "sprites/point_gren.spr", pev->origin + Vector (0,0,72), TRUE) ;
	}

	void Precache( void )
	{
                //PRECACHE_MODEL ("models/w_ARgrenade.mdl");
                PRECACHE_MODEL("models/w_grenade.mdl");
		PRECACHE_SOUND("items/9mmclip1.wav");
                PRECACHE_MODEL("sprites/point_gren.spr");
	}
	BOOL AddAmmo( CBaseEntity *pOther ) 
        {                                    
                //int bResult = (pOther->GiveAmmo( 1, "ARgrenades", M203_GRENADE_MAX_CARRY ) != -1);
                int bResult = (pOther->GiveAmmo( 1, "Hand Grenade", M203_GRENADE_MAX_CARRY ) != -1);

		if (bResult)
		{
			EMIT_SOUND(ENT(pev), CHAN_ITEM, "items/9mmclip1.wav", 1, ATTN_NORM);
                        UTIL_Remove( pointersprite );
		}
		return bResult;
	}
};
LINK_ENTITY_TO_CLASS( ammo_mp5grenades, CMP5AmmoGrenade );
LINK_ENTITY_TO_CLASS( ammo_ARgrenades, CMP5AmmoGrenade );


















